pub struct LocalAssetOwner<MatchAssetId, AssetInspect, AccountId, AssetId, L = Location>(/* private fields */);Expand description
Origin check that verifies that an origin is the owner of a local trusted asset.
- Allows signed origins
- Checks that the asset exists
- The origin must be the owner of the asset